summaryrefslogtreecommitdiff
path: root/src/script/script_config.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/script_config.hpp')
-rw-r--r--src/script/script_config.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/script/script_config.hpp b/src/script/script_config.hpp
index 3dfd6bb0b..db04397a7 100644
--- a/src/script/script_config.hpp
+++ b/src/script/script_config.hpp
@@ -61,10 +61,10 @@ protected:
public:
ScriptConfig() :
- name(NULL),
+ name(nullptr),
version(-1),
- info(NULL),
- config_list(NULL),
+ info(nullptr),
+ config_list(nullptr),
is_random(false)
{}
@@ -178,7 +178,7 @@ public:
* Search a textfile file next to this script.
* @param type The type of the textfile to search for.
* @param slot #CompanyID to check status of.
* @return The filename for the textfile, \c NULL otherwise.
*/
const char *GetTextfile(TextfileType type, CompanyID slot) const;
@@ -178,7 +178,7 @@ public:
* @param type The type of the textfile to search for.
* @param slot #CompanyID to check status of.
- * @return The filename for the textfile, \c NULL otherwise.
+ * @return The filename for the textfile, \c nullptr otherwise.
*/
const char *GetTextfile(TextfileType type, CompanyID slot) const;